This is a port of Henning Kralsen's UTFT library for Arduino/chipKIT to mbed, refactored to make full use of C inheritance and access control, in order to reduce work when implementing new drivers and at the same time make the code more readable and easier to maintain. As of now supported are SSD1289 (16-bit interface), HX8340-B (serial interface) and ST7735 (serial interface). Drivers for other controllers will be added as time and resources to acquire the displays to test the code permit.

Dependents:   UTFT_SSD1289

Fork of TFTLCD by Todor Todorov

Revision:
7:5c418fc1879f
Parent:
6:059ca1648211
Child:
8:7a4791dbb065
--- a/lcd_base.h	Mon Dec 03 15:38:56 2012 +0000
+++ b/lcd_base.h	Tue Dec 04 02:26:44 2012 +0000
@@ -100,11 +100,6 @@
     unsigned char  numchars; /**< Count of the available characters in the font. */
 } font_metrics_t;
 
-/** \typedef bitmap_t
- *  \brief Pointer to the start of a block of pixel data, describing a picture.
- */
-typedef unsigned short* bitmap_t;
-
 /** Base class for LCD implementations.
  *
  * All separate LCD controller implementations have to subclass this one.
@@ -315,10 +310,10 @@
      * \param y Vertical offset of the first pixel of the image
      * \param sx Width of the image.
      * \param sy Height of the image.
      * \param data Image pixel array.
      * \param scale A value of 1 will produce an image with its original size, while a different value will scale the image.
      */
-    virtual void DrawBitmap( unsigned short x, unsigned short y, unsigned short sx, unsigned short sy, bitmap_t data, unsigned char scale = 1 );
+    virtual void DrawBitmap( unsigned short x, unsigned short y, unsigned short sx, unsigned short sy, const unsigned short* imgPixelData, unsigned char scale = 1 );
     
     /** Draw an image on the screen.
      *
@@ -332,12 +327,12 @@
      * \param y Vertical offset of the first pixel of the image
      * \param sx Width of the image.
      * \param sy Height of the image.
      * \param data Image pixel array.
      * \param deg Angle to rotate the image before painting on screen, in degrees.
      * \param rox
      * \param roy
      */
-    virtual void DrawBitmap( unsigned short x, unsigned short y, unsigned short sx, unsigned short sy, bitmap_t data, unsigned short deg, unsigned short rox, unsigned short roy );
+    virtual void DrawBitmap( unsigned short x, unsigned short y, unsigned short sx, unsigned short sy, const unsigned short* imgPixelData, unsigned short deg, unsigned short rox, unsigned short roy );
     
 protected:
     /** Creates an instance of the class.
@@ -315,10 +310,10 @@
      * \param sx Width of the image.
      * \param sy Height of the image.
-     * \param data Image pixel array.
+     * \param imgPixelData Image pixel array.
      * \param scale A value of 1 will produce an image with its original size, while a different value will scale the image.
      */
@@ -332,12 +327,12 @@
      * \param sx Width of the image.
      * \param sy Height of the image.
-     * \param data Image pixel array.
+     * \param imgPixelData Image pixel array.
      * \param deg Angle to rotate the image before painting on screen, in degrees.
      * \param rox